@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
+from django import VERSION as DJANGO_VERSION
 from django.db import router
 from django.db.models import signals
 from django.db.models.fields.related import add_lazy_relation, create_many_related_manager
 from django.db.models.fields.related import ManyToManyField, ReverseManyRelatedObjectsDescriptor
 from django.db.models.fields.related import RECURSIVE_RELATIONSHIP_CONSTANT
+from django.conf import settings
 from django.utils.functional import curry
 from sortedm2m.forms import SortedMultipleChoiceField
 
@@ -151,15 +153,21 @@ class ReverseSortedManyRelatedObjectsDescriptor(ReverseManyRelatedObjectsDescrip
         superclass = rel_model._default_manager.__class__
         RelatedManager = create_sorted_many_related_manager(superclass, self.field.rel)
 
-        manager = RelatedManager(
-            model=rel_model,
-            core_filters={'%s__pk' % self.field.related_query_name(): instance._get_pk_val()},
-            instance=instance,
-            symmetrical=(self.field.rel.symmetrical and isinstance(instance, rel_model)),
-            source_field_name=self.field.m2m_field_name(),
-            target_field_name=self.field.m2m_reverse_field_name(),
-            reverse=False
-        )
+        init_kwargs = {
+            'model': rel_model,
+            'instance': instance,
+            'symmetrical': (self.field.rel.symmetrical and isinstance(instance, rel_model)),
+            'source_field_name': self.field.m2m_field_name(),
+            'target_field_name': self.field.m2m_reverse_field_name(),
+            'reverse': False,
+        }
+
+        if DJANGO_VERSION[:2] >= (1, 4):
+            init_kwargs['through'] = self.field.rel.through
+            init_kwargs['query_field_name'] = self.field.related_query_name()
+        else:
+            init_kwargs['core_filters'] = {'%s__pk' % self.field.related_query_name(): instance._get_pk_val()}
+        manager = RelatedManager(**init_kwargs)
 
         return manager
 
@@ -242,7 +250,7 @@ try:
 except ImportError:
     south = None
 
-if south is not None:
+if south is not None and 'south' in settings.INSTALLED_APPS:
     from south.modelsinspector import add_introspection_rules
     add_introspection_rules(
         [(
